@@ -30,6 +30,9 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #endif // _WIN32
 
 #include "scap.h"
+#ifndef _WIN32
+#include "../../driver/driver_config.h"
+#endif // _WIN32
 #include "../../driver/ppm_ringbuffer.h"
 #include "scap_savefile.h"
 #include "scap-int.h"
@@ -177,7 +180,7 @@ scap_t* scap_open_live_int(char *error,
 		//
 		// Open the device
 		//
-		sprintf(filename, "%s/dev/sysdig%d", scap_get_host_root(), all_scanned_devs);
+		sprintf(filename, "%s/dev/" PROBE_DEVICE_NAME "%d", scap_get_host_root(), all_scanned_devs);
 
 		if((handle->m_devs[j].m_fd = open(filename, O_RDWR | O_SYNC)) < 0)
 		{
@@ -195,7 +198,7 @@ scap_t* scap_open_live_int(char *error,
 			}
 			else
 			{
-				snprintf(error, SCAP_LASTERR_SIZE, "error opening device %s. Make sure you have root credentials and that the sysdig-probe module is loaded.", filename);
+				snprintf(error, SCAP_LASTERR_SIZE, "error opening device %s. Make sure you have root credentials and that the " PROBE_NAME " module is loaded.", filename);
 			}
 
 			scap_close(handle);
