@@ -380,47 +380,48 @@ public:
 		TYPE_DELTA = 13,
 		TYPE_DELTA_S = 14,
 		TYPE_DELTA_NS = 15,
-		TYPE_DIR = 16,
-		TYPE_TYPE = 17,
-		TYPE_TYPE_IS = 18,
-		TYPE_SYSCALL_TYPE = 19,
-		TYPE_CATEGORY = 20,
-		TYPE_CPU = 21,
-		TYPE_ARGS = 22,
-		TYPE_ARGSTR = 23,
-		TYPE_ARGRAW = 24,
-		TYPE_INFO = 25,
-		TYPE_BUFFER = 26,
-		TYPE_BUFLEN = 27,
-		TYPE_RESSTR = 28,
-		TYPE_RESRAW = 29,
-		TYPE_FAILED = 30,
-		TYPE_ISIO = 31,
-		TYPE_ISIO_READ = 32,
-		TYPE_ISIO_WRITE = 33,
-		TYPE_IODIR = 34,
-		TYPE_ISWAIT = 35,
-		TYPE_WAIT_LATENCY = 36,
-		TYPE_ISSYSLOG = 37,
-		TYPE_COUNT = 38,
-		TYPE_COUNT_ERROR = 39,
-		TYPE_COUNT_ERROR_FILE = 40,
-		TYPE_COUNT_ERROR_NET = 41,
-		TYPE_COUNT_ERROR_MEMORY = 42,
-		TYPE_COUNT_ERROR_OTHER = 43,
-		TYPE_COUNT_EXIT = 44,
-		TYPE_COUNT_PROCINFO = 45,
-		TYPE_COUNT_THREADINFO = 46,
-		TYPE_AROUND = 47,
-		TYPE_ABSPATH = 48,
-		TYPE_BUFLEN_IN = 49,
-		TYPE_BUFLEN_OUT = 50,
-		TYPE_BUFLEN_FILE = 51,
-		TYPE_BUFLEN_FILE_IN = 52,
-		TYPE_BUFLEN_FILE_OUT = 53,
-		TYPE_BUFLEN_NET = 54,
-		TYPE_BUFLEN_NET_IN = 55,
-		TYPE_BUFLEN_NET_OUT = 56,
+		TYPE_RUNTIME_TIME_OUTPUT_FORMAT = 16,
+		TYPE_DIR = 17,
+		TYPE_TYPE = 18,
+		TYPE_TYPE_IS = 19,
+		TYPE_SYSCALL_TYPE = 20,
+		TYPE_CATEGORY = 21,
+		TYPE_CPU = 22,
+		TYPE_ARGS = 23,
+		TYPE_ARGSTR = 24,
+		TYPE_ARGRAW = 25,
+		TYPE_INFO = 26,
+		TYPE_BUFFER = 27,
+		TYPE_BUFLEN = 28,
+		TYPE_RESSTR = 29,
+		TYPE_RESRAW = 30,
+		TYPE_FAILED = 31,
+		TYPE_ISIO = 32,
+		TYPE_ISIO_READ = 33,
+		TYPE_ISIO_WRITE = 34,
+		TYPE_IODIR = 35,
+		TYPE_ISWAIT = 36,
+		TYPE_WAIT_LATENCY = 37,
+		TYPE_ISSYSLOG = 38,
+		TYPE_COUNT = 39,
+		TYPE_COUNT_ERROR = 40,
+		TYPE_COUNT_ERROR_FILE = 41,
+		TYPE_COUNT_ERROR_NET = 42,
+		TYPE_COUNT_ERROR_MEMORY = 43,
+		TYPE_COUNT_ERROR_OTHER = 44,
+		TYPE_COUNT_EXIT = 45,
+		TYPE_COUNT_PROCINFO = 46,
+		TYPE_COUNT_THREADINFO = 47,
+		TYPE_AROUND = 48,
+		TYPE_ABSPATH = 49,
+		TYPE_BUFLEN_IN = 50,
+		TYPE_BUFLEN_OUT = 51,
+		TYPE_BUFLEN_FILE = 52,
+		TYPE_BUFLEN_FILE_IN = 53,
+		TYPE_BUFLEN_FILE_OUT = 54,
+		TYPE_BUFLEN_NET = 55,
+		TYPE_BUFLEN_NET_IN = 56,
+		TYPE_BUFLEN_NET_OUT = 57
 	};
 
 	sinsp_filter_check_event();
@@ -432,7 +433,6 @@ public:
 	Json::Value extract_as_js(sinsp_evt *evt, OUT uint32_t* len);
 	bool compare(sinsp_evt *evt);
 
-	uint64_t m_first_ts;
 	uint64_t m_u64val;
 	uint64_t m_tsdelta;
 	uint32_t m_u32val;
