@@ -457,23 +457,26 @@ void handle_end_of_file(bool print_progress, sinsp_evt_formatter* formatter = NU
 // Event processing loop
 //
 captureinfo do_inspect(sinsp* inspector,
-					   uint64_t cnt,
-					   bool quiet,
-					   bool json,
-					   bool print_progress,
-					   sinsp_filter* display_filter,
-					   vector<summary_table_entry>* summary_table,
-					   sinsp_evt_formatter* formatter)
+	uint64_t cnt,
+	bool quiet,
+	bool json,
+	bool do_flush,
+	bool print_progress,
+	sinsp_filter* display_filter,
+	vector<summary_table_entry>* summary_table,
+	sinsp_evt_formatter* formatter)
 {
 	captureinfo retval;
 	int32_t res;
 	sinsp_evt* ev;
-	uint64_t ts;
-	uint64_t deltats = 0;
-	uint64_t firstts = 0;
 	string line;
 	double last_printed_progress_pct = 0;
 
+	if(json)
+	{
+		do_flush = true;
+	}
+
 	//
 	// Loop through the events
 	//
@@ -522,13 +525,6 @@ captureinfo do_inspect(sinsp* inspector,
 
 		retval.m_nevts++;
 
-		ts = ev->get_ts();
-		if(firstts == 0)
-		{
-			firstts = ts;
-		}
-		deltats = ts - firstts;
-
 		if(print_progress)
 		{
 			if(ev->get_num() % 10000 == 0)
@@ -619,15 +615,15 @@ captureinfo do_inspect(sinsp* inspector,
 				{
 					cout << endl;
 				}
-				else
-				{
-					cout << flush;
-				}
 			}
 		}
+
+		if(do_flush)
+		{
+			cout << flush;
+		}
 	}
 
-	retval.m_time = deltats;
 	return retval;
 }
 
@@ -658,9 +654,9 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 	int32_t n_filterargs = 0;
 	int cflag = 0;
 	bool jflag = false;
+	bool unbuf_flag = false;
 	string cname;
 	vector<summary_table_entry>* summary_table = NULL;
-	string timefmt = "%evt.time";
 
 	// These variables are for the cycle_writer engine
 	int duration_seconds = 0;	
@@ -698,6 +694,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 		{"snaplen", required_argument, 0, 's' },
 		{"summary", no_argument, 0, 'S' },
 		{"timetype", required_argument, 0, 't' },
+		{"unbuffered", no_argument, 0, 0 },
 		{"verbose", no_argument, 0, 'v' },
 		{"version", no_argument, 0, 0 },
 		{"writefile", required_argument, 0, 'w' },
@@ -708,7 +705,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 		{0, 0, 0, 0}
 	};
 
-	output_format = "*%evt.num <TIME> %evt.cpu %proc.name (%thread.tid) %evt.dir %evt.type %evt.info";
+	output_format = "*%evt.num %evt.outputtime %evt.cpu %proc.name (%thread.tid) %evt.dir %evt.type %evt.info";
 
 	try
 	{
@@ -908,14 +905,13 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 					//
 					// -pp shows the default output format, useful if the user wants to tweak it.
 					//
-					replace_in_place(output_format, "<TIME>", timefmt);
 					printf("%s\n", output_format.c_str());
 					delete inspector;
 					return sysdig_init_res(EXIT_SUCCESS);
 				}
 				else if(string(optarg) == "c" || string(optarg) == "container")
 				{
-					output_format = "*%evt.num <TIME> %evt.cpu %container.name (%container.id) %proc.name (%thread.tid:%thread.vtid) %evt.dir %evt.type %evt.info";
+					output_format = "*%evt.num %evt.outputtime %evt.cpu %container.name (%container.id) %proc.name (%thread.tid:%thread.vtid) %evt.dir %evt.type %evt.info";
 
 					//
 					// This enables chisels to determine if they should print container information
@@ -958,25 +954,9 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				{
 					string tms(optarg);
 
-					if(tms == "h")
+					if(tms == "h" || tms == "a" || tms == "r" || tms == "d" || tms == "D")
 					{
-						timefmt = "%evt.time";
-					}
-					else if(tms == "a")
-					{
-						timefmt = "%evt.rawtime.s.%evt.rawtime.ns";
-					}
-					else if(tms == "r")
-					{
-						timefmt = "%evt.reltime.s.%evt.reltime.ns";
-					}
-					else if(tms == "d")
-					{
-						timefmt = "%evt.latency.s.%evt.latency.ns";
-					}
-					else if(tms == "D")
-					{
-						timefmt = "%evt.deltatime.s.%evt.deltatime.ns";
+						inspector->set_time_output_mode(tms.c_str()[0]);
 					}
 					else
 					{
@@ -1043,6 +1023,11 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				delete inspector;
 				return sysdig_init_res(EXIT_SUCCESS);
 			}
+
+			if(string(long_options[long_index].name) == "unbuffered")
+			{
+				unbuf_flag = true;
+			}
 		}
 
 		//
@@ -1139,11 +1124,6 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 			goto exit;
 		}
 
-		//
-		// Insert the right time format based on the -t flag
-		//
-		replace_in_place(output_format, "<TIME>", timefmt);
-
 		//
 		// Create the event formatter
 		//
@@ -1208,13 +1188,6 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				{
 					open_success = false;
 				}
-#else
-				//
-				// Starting live capture
-				// If this fails on Windows and OSX, don't try with any driver
-				//
-				inspector->open("");
-#endif
 
 				//
 				// Starting the live capture failed, try to load the driver with
@@ -1224,13 +1197,20 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				{
 					open_success = true;
 
-					if(system("modprobe sysdig-probe > /dev/null 2> /dev/null"))
+					if(system("modprobe " PROBE_NAME " > /dev/null 2> /dev/null"))
 					{
 						fprintf(stderr, "Unable to load the driver\n");						
 					}
 
 					inspector->open("");
 				}
+#else
+				//
+				// Starting live capture
+				// If this fails on Windows and OSX, don't try with any driver
+				//
+				inspector->open("");
+#endif
 
 				//
 				// Enable gathering the CPU from the kernel module
@@ -1260,6 +1240,7 @@ sysdig_init_res sysdig_init(int argc, char **argv)
 				cnt,
 				quiet,
 				jflag,
+				unbuf_flag,
 				print_progress,
 				display_filter,
 				summary_table,
