@@ -19,6 +19,9 @@ along with sysdig.  If not, see <http://www.gnu.org/licenses/>.
 #pragma once
 
 #include <config_sysdig.h>
+#ifndef _WIN32
+#include "../../driver/driver_config.h"
+#endif // _WIN32
 
 //
 // ASSERT implementation
